# Caqtus

[![PyPI](https://img.shields.io/pypi/v/caqtus-suite)](https://pypi.org/project/caqtus-suite/)
![versions](https://img.shields.io/pypi/pyversions/caqtus-suite)
[![doc](https://readthedocs.org/projects/caqtus/badge/?version=latest)](https://caqtus.readthedocs.io)


The `caqtus` package can be used to run precisely timed cold atom experiments.

<img src="doc/source/_static/screenshot.png" width="960" alt="Screenshot of the GUI">

## Documentation

Some documentation can be found [here](https://caqtus.readthedocs.io/en/latest/).
